Enum async_proto::ReadError [−][src]
pub enum ReadError {
}Variants
BufSize(TryFromIntError)Received a buffer with more than usize::MAX elements
Tuple Fields of BufSize
Custom(String)An error variant you can use when manually implementing Protocol
Tuple Fields of Custom
0: StringThe end of the stream was encountered before a complete value was read.
Note that this error condition may also be represented as a ReadError::Io with kind UnexpectedEof.
This is supported on crate feature
serde_json only.Attempted to read an empty type
Tungstenite(Arc<Error>)This is supported on crate feature
tokio-tungstenite only.Tuple Fields of Tungstenite
0: Arc<Error>UnknownVariant8(u8)Tuple Fields of UnknownVariant8
0: u8UnknownVariant16(u16)Tuple Fields of UnknownVariant16
0: u16UnknownVariant32(u32)Tuple Fields of UnknownVariant32
0: u32UnknownVariant64(u64)Tuple Fields of UnknownVariant64
0: u64Utf8(FromUtf8Error)Tuple Fields of Utf8
This is supported on crate feature
warp only.Trait Implementations
Performs the conversion.
Performs the conversion.